@@ -169,7 +169,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.22'
+__version__ = '0.1.25'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -787,10 +787,6 @@ class LiszDataMixin(ABC):
 
         return {k: v for k, v in locals().items() if not what or k in what}
 
-    def on_app_init(self):
-        """ initialize self.current_node_items from flow_id/flow_path saved on last app stop. """
-        self.refresh_current_node_items_from_flow_path()
-
     def on_app_state_root_node_save(self, root_node: LiszNode) -> LiszNode:
         """ shrink root_node app state variable before it get saved to the config file. """
         self.shrink_node_size(root_node)
@@ -879,24 +875,26 @@ class LiszDataMixin(ABC):
 
         return True         # key press processed
 
-    def on_item_enter(self, _key: str, _event_kwargs: dict) -> bool:
+    def on_item_enter(self, _key: str, event_kwargs: dict) -> bool:
         """ entering sub node from current node.
 
         :param _key:            flow key (item id).
-        :param _event_kwargs:   event kwargs.
+        :param event_kwargs:    event kwargs.
         :return:                True for to process/change flow id.
         """
         self.play_sound(id_of_flow('enter', 'item'))
+        event_kwargs['changed_event_name'] = 'refresh_all'
         return True
 
-    def on_item_leave(self, _key: str, _event_kwargs: dict) -> bool:
+    def on_item_leave(self, _key: str, event_kwargs: dict) -> bool:
         """ leaving sub node, setting current node to parent node.
 
         :param _key:            flow key (item id).
-        :param _event_kwargs:   event kwargs.
+        :param event_kwargs:    event kwargs.
         :return:                True for to process/change flow id.
         """
         self.play_sound(id_of_flow('leave', 'item'))
+        event_kwargs['changed_event_name'] = 'refresh_all'
         return True
 
     def on_item_sel_toggle(self, item_id: str, event_kwargs: dict) -> bool:
@@ -913,7 +911,7 @@ class LiszDataMixin(ABC):
     def on_item_sel_change(self, item_id: str, event_kwargs: dict) -> bool:
         """ toggle, set or reset in the current node the selection of a leaf item or of the sub-leaves of a node item.
 
-        :param item_id:         item id of the leaf to toggle selection for.
+        :param item_id:         item id of the leaf/node to toggle selection for.
         :param event_kwargs:    event kwargs, containing a `set_sel_to` key with a boolean value, where
                                 True will select and False deselect the item (or the sub-items if the item is a
                                 non-empty sub-node).
@@ -998,14 +996,16 @@ class LiszDataMixin(ABC):
         if self.flow_path_action(flow_path) == 'enter' and self.flow_path_action() == 'open':
             flow_path.append(self.flow_path[-1])
 
-        self.change_app_state('flow_path', flow_path, send_event=False)
-        event_kwargs['flow_id'] = id_of_flow('', '')
+        self.change_app_state('flow_path', flow_path)
+        # noinspection PyAttributeOutsideInit
+        event_kwargs['flow_id'] = self._last_focus_flow_id = id_of_flow('')     # reset _last_focus_flow_id of last node
         self.play_sound(id_of_flow('enter', 'item'))
+        event_kwargs['changed_event_name'] = 'refresh_all'
 
         return True
 
     def refresh_all(self):
-        """ refresh currently displayed items after changing current node. """
+        """ changed flow event handler refreshing currently displayed items after changing current node/flow path. """
         assert not self._refreshing_data
         self._refreshing_data = True
         try:
@@ -1022,7 +1022,7 @@ class LiszDataMixin(ABC):
             if flow_action(flow_id) == 'focus':
                 item_idx = self.find_item_index(flow_key(flow_id))
                 if item_idx not in self.filtered_indexes:
-                    flow_id = id_of_flow('', '')  # reset flow id because last focused item got filtered/deleted by user
+                    flow_id = id_of_flow('')  # reset flow id because last focused item got filtered/deleted by user
 
             self.change_app_state('flow_id', flow_id, send_event=False)     # correct flow or restore silently
 
